<!DOCTYPE html
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/">
  <head>
    <title>${path}</title>
  </head>
  <body>
    <ul>
      <li py:if="request.path_info.strip('/')"><a href="..">..</a></li>
      <li py:for="f in files"><a href="${f['path']}">${f['description'] or f['name']}</a></li>

    </ul>
   </body>
</html>
